@@ -8,6 +8,8 @@ import (
 
 	"github.com/mitchellh/mapstructure"
 	"github.com/spf13/cobra"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoimaps"
 )
 
 // An EntryTypeSet is a set of entry types. It parses and prints as a
@@ -62,7 +64,7 @@ var (
 		"templates": EntryTypeTemplates,
 	}
 
-	entryTypeStrings = sortedKeys(entryTypeBits)
+	entryTypeStrings = chezmoimaps.SortedKeys(entryTypeBits)
 
 	entryTypeCompletions = []string{
 		"all",
@@ -132,7 +134,7 @@ func (s *EntryTypeSet) ContainsSourceStateEntry(sourceStateEntry SourceStateEntr
 		default:
 			return false
 		}
-	case *SourceStateDir:
+	case *SourceStateDir, *SourceStateImplicitDir:
 		switch {
 		case s.bits&EntryTypeExternals != 0 && isExternal:
 			return true
@@ -369,9 +371,7 @@ func StringSliceToEntryTypeSetHookFunc() mapstructure.DecodeHookFunc {
 }
 
 // EntryTypeSetFlagCompletionFunc completes EntryTypeSet flags.
-func EntryTypeSetFlagCompletionFunc(
-	cmd *cobra.Command, args []string, toComplete string,
-) ([]string, cobra.ShellCompDirective) {
+func EntryTypeSetFlagCompletionFunc(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 	var completions []string
 	entryTypes := strings.Split(toComplete, ",")
 	lastEntryType := entryTypes[len(entryTypes)-1]
