@@ -1132,15 +1132,17 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 			switch _, err := s.system.Lstat(destAbsPath); {
 			case errors.Is(err, fs.ErrNotExist):
 				// FIXME add support for using builtin git
-				args := []string{"clone"}
-				args = append(args, external.Clone.Args...)
-				args = append(args, external.URL, destAbsPath.String())
-				cmd := exec.Command("git", args...)
-				cmd.Stdin = os.Stdin
-				cmd.Stdout = os.Stdout
-				cmd.Stderr = os.Stderr
 				sourceStateCommand := &SourceStateCommand{
-					cmd:           cmd,
+					cmd: newLazyCommandFunc(func() *exec.Cmd {
+						args := []string{"clone"}
+						args = append(args, external.Clone.Args...)
+						args = append(args, external.URL, destAbsPath.String())
+						cmd := exec.Command("git", args...)
+						cmd.Stdin = os.Stdin
+						cmd.Stdout = os.Stdout
+						cmd.Stderr = os.Stderr
+						return cmd
+					}),
 					origin:        external,
 					forceRefresh:  options.RefreshExternals == RefreshExternalsAlways,
 					refreshPeriod: external.RefreshPeriod,
@@ -1153,15 +1155,17 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				return err
 			default:
 				// FIXME add support for using builtin git
-				args := []string{"pull"}
-				args = append(args, external.Pull.Args...)
-				cmd := exec.Command("git", args...)
-				cmd.Dir = destAbsPath.String()
-				cmd.Stdin = os.Stdin
-				cmd.Stdout = os.Stdout
-				cmd.Stderr = os.Stderr
 				sourceStateCommand := &SourceStateCommand{
-					cmd:           cmd,
+					cmd: newLazyCommandFunc(func() *exec.Cmd {
+						args := []string{"pull"}
+						args = append(args, external.Pull.Args...)
+						cmd := exec.Command("git", args...)
+						cmd.Dir = destAbsPath.String()
+						cmd.Stdin = os.Stdin
+						cmd.Stdout = os.Stdout
+						cmd.Stderr = os.Stderr
+						return cmd
+					}),
 					origin:        external,
 					forceRefresh:  options.RefreshExternals == RefreshExternalsAlways,
 					refreshPeriod: external.RefreshPeriod,
