@@ -51,6 +51,7 @@ var (
 	keepassxcMinVersion = semver.Version{Major: 2, Minor: 7, Patch: 0}
 
 	keepassxcEnterPasswordToUnlockDatabaseRx = regexp.MustCompile(`^Enter password to unlock .*: `)
+	keepassxcAnyResponseRx                   = regexp.MustCompile(`(?m)\A.*\r\n`)
 	keepassxcPairRx                          = regexp.MustCompile(`^([A-Z]\w*):\s*(.*)$`)
 	keepassxcPromptRx                        = regexp.MustCompile(`^.*> `)
 )
@@ -196,11 +197,17 @@ func (c *Config) keepassxcOutputOpen(command string, args ...string) ([]byte, er
 			return nil, err
 		}
 
-		// Start the keepassxc-cli open command. Set the LANGUAGE environment
-		// variable to ensure that the prompt is in US English.
+		// Start the keepassxc-cli open command.
 		cmdArgs := append(slices.Clone(c.Keepassxc.Args), "open", c.Keepassxc.Database.String())
 		cmd := exec.Command(c.Keepassxc.Command, cmdArgs...) //nolint:gosec
-		cmd.Env = append(os.Environ(), "LANGUAGE=en")
+		env := os.Environ()
+		// Ensure prompt is in English.
+		env = append(env, "LANGUAGE=en")
+		// Reduce injection of terminal control characters.
+		env = slices.DeleteFunc(env, func(s string) bool {
+			return strings.HasPrefix(s, "TERM=")
+		})
+		cmd.Env = env
 		cmd.Stdin = console.Tty()
 		cmd.Stdout = console.Tty()
 		cmd.Stderr = console.Tty()
@@ -210,10 +217,16 @@ func (c *Config) keepassxcOutputOpen(command string, args ...string) ([]byte, er
 
 		if c.Keepassxc.Prompt {
 			// Expect the password prompt, e.g. "Enter password to unlock $HOME/Passwords.kdbx: ".
-			enterPasswordToUnlockPrompt, err := console.Expect(expect.Regexp(keepassxcEnterPasswordToUnlockDatabaseRx))
+			enterPasswordToUnlockPrompt, err := console.Expect(
+				expect.Regexp(keepassxcEnterPasswordToUnlockDatabaseRx),
+				expect.Regexp(keepassxcAnyResponseRx),
+			)
 			if err != nil {
 				return nil, err
 			}
+			if !keepassxcEnterPasswordToUnlockDatabaseRx.MatchString(enterPasswordToUnlockPrompt) {
+				return nil, errors.New(strings.TrimSpace(enterPasswordToUnlockPrompt))
+			}
 
 			// Read the password from the user, if necessary.
 			var password string
@@ -238,10 +251,16 @@ func (c *Config) keepassxcOutputOpen(command string, args ...string) ([]byte, er
 		}
 
 		// Read the prompt, e.g "Passwords> ", so we can expect it later.
-		output, err := console.Expect(expect.Regexp(keepassxcPromptRx))
+		output, err := console.Expect(
+			expect.Regexp(keepassxcPromptRx),
+			expect.Regexp(keepassxcAnyResponseRx),
+		)
 		if err != nil {
 			return nil, err
 		}
+		if !keepassxcPromptRx.MatchString(output) {
+			return nil, errors.New(strings.TrimSpace(output))
+		}
 
 		c.Keepassxc.cmd = cmd
 		c.Keepassxc.console = console
@@ -269,9 +288,6 @@ func (c *Config) keepassxcOutputOpen(command string, args ...string) ([]byte, er
 	outputLines := strings.Split(output, "\r\n")
 
 	// Trim the echoed command from the output, which is the first line.
-	// keepassxc-cli version 2.7.6 on macOS inserts " \b" somewhere in the
-	// echoed command. Rather than trying to match this, remove the first line
-	// entirely.
 	if len(outputLines) > 0 {
 		outputLines = outputLines[1:]
 	}
